# Overview

## Guides

* [Quick start](quick-start.md) - A quick start guide for new projects.
* [Installation details](installation.md) - A step by step installation guide.


## Management commands

CjkCMS offers a [set of management commands](management_commands/index.md) to help you manage your content.
* `init-collections` - Initialize either a default set of collections, or a custom set.
* `clear-embeds` - Clear OEmbed cache. 

## How to guides
* Protected Vimeo content - [custom OEmbed finder](how-to/oembed_finder.md)
